<!--
SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

## Info

- program: licensecheck
- version: 2025.1.0
- license: MIT LICENSE

## Project License

MPL LICENSE

## Packages

Find a list of packages below

|Compatible|Package|
|:--|:--|
|✔|aiobotocore|
|✔|aiohappyeyeballs|
|✔|aiohttp|
|✔|aioitertools|
|✔|aiosignal|
|✔|alembic|
|✔|annotated-types|
|✔|anyio|
|✔|attrs|
|✔|authlib|
|✔|blinker|
|✔|botocore|
|✔|cachetools|
|✔|certifi|
|✔|cffi|
|✔|charset-normalizer|
|✔|click|
|✔|cloudpickle|
|✔|contourpy|
|✔|cryptography|
|✔|cycler|
|✔|cyclopts|
|✔|databricks-sdk|
|✔|dnspython|
|✔|docker|
|✔|docstring-parser|
|✔|docutils|
|✔|email-validator|
|✔|exceptiongroup|
|✔|fastapi|
|✔|fastmcp|
|✔|flask|
|✔|fonttools|
|✔|frozenlist|
|✔|fsspec|
|✔|gitdb|
|✔|gitpython|
|✔|google-auth|
|✔|graphene|
|✔|graphql-core|
|✔|graphql-relay|
|✔|gunicorn|
|✔|h11|
|✔|h5py|
|✔|holidays|
|✔|httpcore|
|✔|httpx|
|✔|httpx-sse|
|✔|idna|
|✔|importlib-metadata|
|✔|isodate|
|✔|itsdangerous|
|✔|jinja2|
|✔|jmespath|
|✔|joblib|
|✔|jsonschema|
|✔|jsonschema-path|
|✔|jsonschema-specifications|
|✔|kiwisolver|
|✔|lazy-object-proxy|
|✔|mako|
|✔|markdown-it-py|
|✔|markupsafe|
|✔|matplotlib|
|✔|mcp|
|✔|mdurl|
|✔|mlflow|
|✔|mlflow-skinny|
|✔|mlflow-tracing|
|✔|more-itertools|
|✔|multidict|
|✔|narwhals|
|✔|numpy|
|✔|openapi-core|
|✔|openapi-pydantic|
|✔|openapi-schema-validator|
|✔|openapi-spec-validator|
|✔|openstef-beam|
|✔|openstef-compatibility|
|✔|openstef-core|
|✔|openstef-models|
|✔|opentelemetry-api|
|✔|opentelemetry-proto|
|✔|opentelemetry-sdk|
|✔|opentelemetry-semantic-conventions|
|✔|packaging|
|✔|pandas|
|✔|parse|
|✔|pathable|
|✔|pillow|
|✔|plotly|
|✔|propcache|
|✔|protobuf|
|✔|pvlib|
|✔|pyarrow|
|✔|pyasn1|
|✔|pyasn1-modules|
|✔|pycountry|
|✔|pycparser|
|✔|pydantic|
|✔|pydantic-core|
|✔|pydantic-extra-types|
|✔|pydantic-settings|
|✔|pygments|
|✔|pyparsing|
|✔|pyperclip|
|✔|python-dateutil|
|✔|python-dotenv|
|✔|python-multipart|
|✔|pytz|
|✔|pyyaml|
|✔|referencing|
|✔|requests|
|✔|rfc3339-validator|
|✔|rich|
|✔|rich-rst|
|✔|rpds-py|
|✔|rsa|
|✔|s3fs|
|✔|scikit-learn|
|✔|scipy|
|✔|scoringrules|
|✔|six|
|✔|smmap|
|✔|sniffio|
|✔|sqlalchemy|
|✔|sqlparse|
|✔|sse-starlette|
|✔|starlette|
|✔|threadpoolctl|
|✔|tqdm|
|✔|typing-extensions|
|✔|typing-inspection|
|✔|tzdata|
|✔|urllib3|
|✔|uvicorn|
|✔|werkzeug|
|✔|wrapt|
|✔|xgboost|
|✔|yarl|
|✔|zipp|

### aiobotocore-2.24.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 295771

### aiohappyeyeballs-2.6.1

- HomePage: UNKNOWN
- Author: J. Nick Koston
- License: PYTHON SOFTWARE FOUNDATION LICENSE
- Compatible: True
- Size: 40336

### aiohttp-3.12.15

- HomePage: https://github.com/aio-libs/aiohttp
- Author: UNKNOWN
- License: APACHE-2.0;; MIT
- Compatible: True
- Size: 1706783

### aioitertools-0.12.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 89834

### aiosignal-1.4.0

- HomePage: https://github.com/aio-libs/aiosignal
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 16634

### alembic-1.16.5

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 1011301

### annotated-types-0.7.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 36458

### anyio-4.11.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 434487

### attrs-23.2.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 202960

### authlib-1.6.5

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 729490

### blinker-1.9.0

- HomePage: UNKNOWN
- Author: Jason Kirtland
- License: MIT LICENSE
- Compatible: True
- Size: 23895

### botocore-1.40.18

- HomePage: https://github.com/boto/botocore
- Author: Amazon Web Services
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 18174452

### cachetools-6.2.0

- HomePage: https://github.com/tkem/cachetools/
- Author: Thomas Kemmer
- License: MIT LICENSE
- Compatible: True
- Size: 42262

### certifi-2025.8.3

- HomePage: https://github.com/certifi/python-certifi
- Author: Kenneth Reitz
- License: MOZILLA PUBLIC LICENSE 2.0 _MPL 2.0_
- Compatible: True
- Size: 294877

### cffi-2.0.0

- HomePage: UNKNOWN
- Author: Armin Rigo, Maciej Fijalkowski
- License: MIT
- Compatible: True
- Size: 592806

### charset-normalizer-3.4.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 826775

### click-8.3.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 384013

### cloudpickle-3.1.1

- HomePage: https://github.com/cloudpipe/cloudpickle
- Author: The cloudpickle developer team
- License: BSD LICENSE
- Compatible: True
- Size: 66238

### contourpy-1.3.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 999430

### cryptography-45.0.7

- HomePage: UNKNOWN
- Author: The cryptography developers <cryptography-dev@python.org>
- License: APACHE-2.0;; BSD-3-CLAUSE
- Compatible: True
- Size: 21915908

### cycler-0.12.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 22086

### cyclopts-3.24.0

- HomePage: https://github.com/BrianPugh/cyclopts
- Author: Brian Pugh
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 311827

### databricks-sdk-0.67.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 4967593

### dnspython-2.8.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: ISC LICENSE _ISCL_
- Compatible: True
- Size: 1082678

### docker-7.1.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 505472

### docstring-parser-0.17.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 173695

### docutils-0.21.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE;; GNU GENERAL PUBLIC LICENSE _GPL_;; PUBLIC DOMAIN;; PYTHON SOFTWARE FOUNDATION LICENSE
- Compatible: True
- Size: 2031660

### email-validator-2.3.0

- HomePage: https://github.com/JoshData/python-email-validator
- Author: Joshua Tauberer
- License: THE UNLICENSE _UNLICENSE_
- Compatible: True
- Size: 100034

### exceptiongroup-1.3.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 51020

### fastapi-0.118.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 681886

### fastmcp-2.10.6

- HomePage: UNKNOWN
- Author: Jeremiah Lowin
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 747688

### flask-3.1.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 342710

### fonttools-4.60.1

- HomePage: http://github.com/fonttools/fonttools
- Author: Just van Rossum
- License: MIT
- Compatible: True
- Size: 12576510

### frozenlist-1.7.0

- HomePage: https://github.com/aio-libs/frozenlist
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: 167650

### fsspec-2025.9.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 721918

### gitdb-4.0.12

- HomePage: https://github.com/gitpython-developers/gitdb
- Author: Sebastian Thiel
- License: BSD LICENSE
- Compatible: True
- Size: 178726

### gitpython-3.1.45

- HomePage: https://github.com/gitpython-developers/GitPython
- Author: Sebastian Thiel, Michael Trier
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 687640

### google-auth-2.41.1

- HomePage: https://github.com/googleapis/google-auth-library-python
- Author: Google Cloud Platform
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 757191

### graphene-3.4.3

- HomePage: https://github.com/graphql-python/graphene
- Author: Syrus Akbary
- License: MIT
- Compatible: True
- Size: 353597

### graphql-core-3.2.6

- HomePage: https://github.com/graphql-python/graphql-core
- Author: Christoph Zwerschke
- License: MIT LICENSE
- Compatible: True
- Size: 737601

### graphql-relay-3.2.0

- HomePage: https://github.com/graphql-python/graphql-relay-py
- Author: Syrus Akbary
- License: MIT LICENSE
- Compatible: True
- Size: 42129

### gunicorn-23.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 267780

### h11-0.16.0

- HomePage: https://github.com/python-hyper/h11
- Author: Nathaniel J. Smith
- License: MIT LICENSE
- Compatible: True
- Size: 102693

### h5py-3.14.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 9761627

### holidays-0.81

- HomePage: UNKNOWN
- Author: Vacanza Team
- License: MIT
- Compatible: True
- Size: 3298132

### httpcore-1.0.9

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 285071

### httpx-0.28.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 293419

### httpx-sse-0.4.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 16285

### idna-3.10

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 349141

### importlib-metadata-8.7.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 73867

### isodate-0.7.2

- HomePage: UNKNOWN
- Author: Gerhard Weis
- License: BSD LICENSE
- Compatible: True
- Size: -1

### itsdangerous-2.2.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 45828

### jinja2-3.1.6

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 494554

### jmespath-1.0.1

- HomePage: https://github.com/jmespath/jmespath.py
- Author: James Saryerwinnie
- License: MIT LICENSE
- Compatible: True
- Size: 68638

### joblib-1.5.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 916274

### jsonschema-4.25.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 471887

### jsonschema-path-0.3.4

- HomePage: UNKNOWN
- Author: Artur Maciag
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 32843

### jsonschema-specifications-2025.9.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 44039

### kiwisolver-1.4.9

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 241562

### lazy-object-proxy-1.12.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-2-CLAUSE
- Compatible: True
- Size: 151756

### mako-1.3.10

- HomePage: https://www.makotemplates.org/
- Author: Mike Bayer
- License: MIT LICENSE
- Compatible: True
- Size: 272979

### markdown-it-py-3.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 223421

### markupsafe-3.0.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 72796

### matplotlib-3.10.6

- HomePage: UNKNOWN
- Author: John D. Hunter, Michael Droettboom
- License: PYTHON SOFTWARE FOUNDATION LICENSE
- Compatible: True
- Size: 20572041

### mcp-1.16.0

- HomePage: UNKNOWN
- Author: Anthropic, PBC.
- License: MIT LICENSE
- Compatible: True
- Size: 591332

### mdurl-0.1.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 22522

### mlflow-3.4.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 102328669

### mlflow-skinny-3.4.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 8884998

### mlflow-tracing-3.4.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 5164396

### more-itertools-10.8.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### multidict-6.6.4

- HomePage: https://github.com/aio-libs/multidict
- Author: Andrew Svetlov
- License: APACHE LICENSE 2.0
- Compatible: True
- Size: 171746

### narwhals-2.6.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 1741821

### numpy-2.3.3

- HomePage: UNKNOWN
- Author: Travis E. Oliphant et al.
- License: BSD LICENSE
- Compatible: True
- Size: 19164163

### openapi-core-0.19.5

- HomePage: UNKNOWN
- Author: Artur Maciag
- License: BSD LICENSE
- Compatible: True
- Size: -1

### openapi-pydantic-0.5.1

- HomePage: https://github.com/mike-oakley/openapi-pydantic
- Author: Mike Oakley
- License: MIT LICENSE
- Compatible: True
- Size: 247634

### openapi-schema-validator-0.6.3

- HomePage: https://github.com/python-openapi/openapi-schema-validator
- Author: Artur Maciag
- License: BSD LICENSE
- Compatible: True
- Size: 23165

### openapi-spec-validator-0.7.2

- HomePage: UNKNOWN
- Author: Artur Maciag
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 209349

### openstef-beam-0.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: 
- Compatible: True
- Size: 1770

### openstef-compatibility-0.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: 
- Compatible: True
- Size: 1549

### openstef-core-0.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: 
- Compatible: True
- Size: 1660

### openstef-models-0.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: 
- Compatible: True
- Size: 1832

### opentelemetry-api-1.37.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: 199458

### opentelemetry-proto-1.37.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: 255055

### opentelemetry-sdk-1.37.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: 456058

### opentelemetry-semantic-conventions-0.58b0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: 632226

### packaging-25.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE;; BSD LICENSE
- Compatible: True
- Size: 236486

### pandas-2.3.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 39397080

### parse-1.20.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: -1

### pathable-0.4.4

- HomePage: https://github.com/p1c2u/pathable
- Author: Artur Maciag
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 24536

### pillow-11.3.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT-CMU
- Compatible: True
- Size: 13288839

### plotly-6.3.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 42517068

### propcache-0.3.2

- HomePage: https://github.com/aio-libs/propcache
- Author: Andrew Svetlov
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 157228

### protobuf-6.32.1

- HomePage: https://developers.google.com/protocol-buffers/
- Author: protobuf@googlegroups.com
- License: 3-CLAUSE BSD LICENSE
- Compatible: True
- Size: 1574857

### pvlib-0.13.1

- HomePage: https://github.com/pvlib/pvlib-python
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 30794355

### pyarrow-21.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 111071137

### pyasn1-0.6.1

- HomePage: https://github.com/pyasn1/pyasn1
- Author: Ilya Etingof
- License: BSD LICENSE
- Compatible: True
- Size: 377740

### pyasn1-modules-0.4.2

- HomePage: https://github.com/pyasn1/pyasn1-modules
- Author: Ilya Etingof
- License: BSD LICENSE
- Compatible: True
- Size: 723448

### pycountry-24.6.1

- HomePage: https://github.com/flyingcircusio/pycountry
- Author: Christian Theune
- License: GNU LESSER GENERAL PUBLIC LICENSE V2 _LGPLV2_
- Compatible: True
- Size: 16537867

### pycparser-2.23

- HomePage: https://github.com/eliben/pycparser
- Author: Eli Bendersky
- License: BSD LICENSE
- Compatible: True
- Size: 615290

### pydantic-2.11.9

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 1763250

### pydantic-core-2.33.2

- HomePage: https://github.com/pydantic/pydantic-core
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 4358880

### pydantic-extra-types-2.10.5

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 122686

### pydantic-settings-2.11.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 176729

### pygments-2.19.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 4467169

### pyparsing-3.2.5

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 433720

### pyperclip-1.11.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 30489

### python-dateutil-2.9.0.post0

- HomePage: https://github.com/dateutil/dateutil
- Author: Gustavo Niemeyer
- License: APACHE SOFTWARE LICENSE;; BSD LICENSE
- Compatible: True
- Size: 439501

### python-dotenv-1.1.1

- HomePage: https://github.com/theskumar/python-dotenv
- Author: Saurabh Kumar
- License: BSD LICENSE
- Compatible: True
- Size: 55646

### python-multipart-0.0.20

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 88120

### pytz-2025.2

- HomePage: http://pythonhosted.org/pytz
- Author: Stuart Bishop
- License: MIT LICENSE
- Compatible: True
- Size: 957583

### pyyaml-6.0.3

- HomePage: https://pyyaml.org/
- Author: Kirill Simonov
- License: MIT LICENSE
- Compatible: True
- Size: 604277

### referencing-0.36.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 113851

### requests-2.32.4

- HomePage: https://requests.readthedocs.io
- Author: Kenneth Reitz
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 203651

### rfc3339-validator-0.1.4

- HomePage: https://github.com/naimetti/rfc3339-validator
- Author: Nicolas Aimetti
- License: MIT LICENSE
- Compatible: True
- Size: 4009

### rich-14.1.0

- HomePage: https://github.com/Textualize/rich
- Author: Will McGugan
- License: MIT LICENSE
- Compatible: True
- Size: 954426

### rich-rst-1.3.1

- HomePage: https://wasi-master.github.io/rich-rst
- Author: Wasi Master
- License: MIT LICENSE
- Compatible: True
- Size: 41949

### rpds-py-0.27.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 941226

### rsa-4.9.1

- HomePage: UNKNOWN
- Author: Sybren A. Stüvel
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 94486

### s3fs-2025.9.0

- HomePage: http://github.com/fsspec/s3fs/
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 108629

### scikit-learn-1.7.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 31339167

### scipy-1.16.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 72685323

### scoringrules-0.8.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE;; MIT LICENSE
- Compatible: True
- Size: 339533

### six-1.17.0

- HomePage: https://github.com/benjaminp/six
- Author: Benjamin Peterson
- License: MIT LICENSE
- Compatible: True
- Size: 37542

### smmap-5.0.2

- HomePage: https://github.com/gitpython-developers/smmap
- Author: Sebastian Thiel
- License: BSD LICENSE
- Compatible: True
- Size: 67920

### sniffio-1.3.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE;; MIT LICENSE
- Compatible: True
- Size: 21891

### sqlalchemy-2.0.43

- HomePage: https://www.sqlalchemy.org
- Author: Mike Bayer
- License: MIT
- Compatible: True
- Size: 8764181

### sqlparse-0.5.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 139709

### sse-starlette-3.0.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: 26284

### starlette-0.48.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 258458

### threadpoolctl-3.6.0

- HomePage: https://github.com/joblib/threadpoolctl
- Author: Thomas Moreau
- License: BSD LICENSE
- Compatible: True
- Size: 66156

### tqdm-4.67.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE;; MOZILLA PUBLIC LICENSE 2.0 _MPL 2.0_
- Compatible: True
- Size: 223209

### typing-extensions-4.15.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: PSF-2.0
- Compatible: True
- Size: 177708

### typing-inspection-0.4.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 52832

### tzdata-2025.2

- HomePage: https://github.com/python/tzdata
- Author: Python Software Foundation
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 528259

### urllib3-2.5.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 421374

### uvicorn-0.37.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 218492

### werkzeug-3.1.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 755586

### wrapt-1.17.3

- HomePage: https://github.com/GrahamDumpleton/wrapt
- Author: Graham Dumpleton
- License: BSD LICENSE
- Compatible: True
- Size: 168758

### xgboost-3.0.5

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 7506242

### yarl-1.20.1

- HomePage: https://github.com/aio-libs/yarl
- Author: Andrew Svetlov
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 322724

### zipp-3.23.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 22363
